AiChatItemWrapper class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- AiChatItemWrapper({required AiChatItem item, required bool isStoredRemotely})
-
constfactory
-
AiChatItemWrapper.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $AiChatItemWrapperCopyWith<
AiChatItemWrapper> -
Create a copy of AiChatItemWrapper
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStoredRemotely → bool
-
no setterinherited
- item → AiChatItem
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AiChatItemWrapper value)) → TResult -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AiChatItemWrapper value)?) → TResult? -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AiChatItemWrapper value)?, {required TResult orElse()}) → TResult -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(AiChatItem item, bool isStoredRemotely)?, {required TResult orElse()}) → TResult -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AiChatItemWrapper to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(AiChatItem item, bool isStoredRemotely)) → TResult -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(AiChatItem item, bool isStoredRemotely)?) → TResult? -
Available on AiChatItemWrapper, provided by the AiChatItemWrapperPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited