AiChatState class abstract

Available extensions
Annotations
  • @freezed

Constructors

AiChatState({@Default.new([]) List<AiChatItemWrapper> items, @Default.new({}) Set<String> pendingRemoteDeletionIds})
const
factory
AiChatState.fromJson(Map<String, dynamic> json)
factory

Properties

conversationItems List<AiConversationItem>

Available on AiChatState, provided by the ChatStateX extension

no setter
copyWith → $AiChatStateCopyWith<AiChatState>
Create a copy of AiChatState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
items List<AiChatItemWrapper>
no setterinherited
pendingRemoteDeletionIds Set<String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AiChatState value)) → TResult

Available on AiChatState, provided by the AiChatStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AiChatState value)?) → TResult?

Available on AiChatState, provided by the AiChatStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AiChatState value)?, {required TResult orElse()}) → TResult

Available on AiChatState, provided by the AiChatStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<AiChatItemWrapper> items, Set<String> pendingRemoteDeletionIds)?, {required TResult orElse()}) → TResult

Available on AiChatState, provided by the AiChatStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AiChatState to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<AiChatItemWrapper> items, Set<String> pendingRemoteDeletionIds)) → TResult

Available on AiChatState, provided by the AiChatStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<AiChatItemWrapper> items, Set<String> pendingRemoteDeletionIds)?) → TResult?

Available on AiChatState, provided by the AiChatStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited